package com.jcg.autoclose;

/**
 * @author Santosh Balgar Sachchidananda
 * This is a demo class showing the try with multiple resources and their order of closing
 */
public class TryWithMultipleResourcesDemo {
    public static void main(String[] args) {
        System.out.println("##### Try with multiple resources demo ####");
        try(MyFirstAutoCloseable mfa = new MyFirstAutoCloseable(); MySecondAutoCloseable msa = new MySecondAutoCloseable()) {
            System.out.println("Inside try block");
            mfa.printHello();
            msa.printHello();
        } catch(Exception ex) {
            System.out.println("Inside catch block");
        }
    }
}

/**
 * MySecondAutoCloseable is an example of AutoCloseable resource
 * All classes implementing AutoCloseable should provide a definition for close method
 */

class MySecondAutoCloseable implements AutoCloseable{
    @Override
    public void close() throws Exception {
        System.out.println("******* MySecondAutoCloseable close() method *******");
    }

    public void printHello() {
        System.out.println("******* Hello!! I am MySecondAutoCloseable, an AutoCloseable resource *******");
    }
}



/**
 * MyFirstAutoCloseable is an example of AutoCloseable resource.
 * All classes implementing AutoCloseable should provide a definition for close method
 */

class MyFirstAutoCloseable implements AutoCloseable{
    @Override
    public void close() throws Exception {
        System.out.println("######## MyFirstAutoCloseable close() method ########");
    }

    public void printHello() {
        System.out.println("######## Hello!! I am MyFirstAutoCloseable, an AutoCloseable resource ########");
    }
}

